@@ -5,7 +5,7 @@ class ConsulService(object):
         '''初始化，连接consul服务器'''
         self._consul = consul.Consul(host, port)
 
-    def registerService(self, name, service_id,host, port, tags=None):
+    def registerService(self, name, service_id,host,port,health_entry='/health', tags=None):
         tags = tags or []
         # 注册服务
         self._consul.agent.service.register(
@@ -15,10 +15,10 @@ class ConsulService(object):
             port=port,
             tags=tags,
             # 健康检查ip端口，检查时间：5,超时时间：30，注销时间：30s
-            check=consul.Check().tcp(host, port, "5s", "30s", "30s"))
+            check=consul.Check().http("http://{}:{}{}".format(host,port,health_entry), "5s", "30s", "30s",None))
 
-    def check(self,host, port, interval, timeout=None, deregister=None):
-        return consul.Check.tcp(host,port,interval,timeout,deregister)
+    def check(self,host,port, interval, timeout=None, deregister=None,header=None,health_entry='/health'):
+        return consul.Check.http("http://{}:{}{}".format(host,port,health_entry),interval,timeout,deregister,header)
 
     def getService(self, name):
         services = self._consul.agent.services()
@@ -46,16 +46,16 @@ if __name__ == '__main__':
     consulService=ConsulService("consul",8500)
     name="jx-attandance-api-10-0-0-1"
     service_id="jx-attendance-api"
-    consulService.registerService(name,service_id,ip,port,tags)
+    consulService.registerService(name,service_id,"10.5.0.247",5000,tags)
 
-    check=consulService.check()
+    check=consulService.check("10.5.0.247",5000,"30s")
     print(check)
-    res=consulService.getService(name)
+    res=consulService.getService(service_id)
     print(res)
-
 """
 
 
 
 
 
+
